import requests
import ybc_config
import sys
from ybc_exception import *

__PREFIX = ybc_config.config['prefix']
__TEL_URL = __PREFIX + ybc_config.uri + '/tel'


def detail(tel=''):
    """
    功能：手机号码归属地信息查询

    参数：tel: 手机号码

    返回：手机号码归属地信息
    """
    if not (isinstance(tel, str) or isinstance(tel, int)):
        raise ParameterTypeError(function_name=sys._getframe().f_code.co_name, error_msg="'tel'")
    if isinstance(tel, str) and (tel == '' or not tel.isdigit() or tel.__len__() != 11):
        raise ParameterValueError(function_name=sys._getframe().f_code.co_name, error_msg="'tel'")
    if isinstance(tel, int) and tel > 0 and str(tel).__len__() != 11:
        raise ParameterValueError(function_name=sys._getframe().f_code.co_name, error_msg="'tel'")

    try:
        url = __TEL_URL
        data = {
            'phone': tel
        }

        for i in range(3):
            r = requests.post(url, data=data)
            if r.status_code == 200:
                res = r.json()['result']
                if res:
                    res_info = {
                        'province': res['province'],
                        'city': res['city'],
                        'company': res['company'],
                        'shouji': tel
                    }
                    return res_info
                else:
                    raise ParameterValueError(function_name=sys._getframe().f_code.co_name, error_msg="'tel'")

        raise ConnectionError('获取翻译结果失败', r._content)
    except (ParameterTypeError, ParameterValueError) as e:
        raise e
    except Exception as e:
        raise InternalError(e, 'ybc_tel')


def main():
    print(detail('18635579617'))
    print(detail(18635579617))


if __name__ == '__main__':
    main()



import unittest
from ybc_tel import *
from ybc_exception import *


class MyTestCase(unittest.TestCase):
    def test_detail_str(self):
        self.assertEqual({'province': '山西', 'city': '太原', 'company': '联通', 'shouji': '18635579617'}, detail('18635579617'))

    def test_detail_int(self):
        self.assertEqual({'province': '山西', 'city': '太原', 'company': '联通', 'shouji': 18635579617}, detail(18635579617))

    def test_detail_exType(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用detail方法时，'tel'参数类型错误。$"):
            detail([])

    def test_detail_exValue(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用detail方法时，'tel'参数不在允许范围内。$"):
            detail('123456789797946')


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

from distutils.core import setup

setup(name='ybc_tel',
      version='1.0.5',
      description='Search the location of mobile phone number.',
      long_description='TSearch the location of mobile phone number.',
      author='hurs',
      author_email='hurs@fenbi.com',
      keywords=['python', 'phone number', 'search'],
      url='http://pip.zhenguanyu.com/',
      packages=['ybc_tel'],
      package_data={'ybc_tel': ['*.py']},
      license='MIT',
      requires=['ybc_config', 'requests', 'ybc_exception']
     )